@@ -321,14 +321,19 @@ class compNet(nn.Module):
         
         self.n = n;
         self.M = M;
+
         
         self.even_index = range(0,2*M,2);
         self.uneven_index = range(1,2*M,2);
-        
+
+        self.Cov = Cov
+
         #-- Hadamard patterns (full basis)
         if type(H)==type(None):
             H = wh.walsh2_matrix(self.n)/self.n
         H = n*H; #fht hadamard transform needs to be normalized
+
+        self.H = H
         
         #-- Hadamard patterns (undersampled basis)
         if type(Ord)==type(None):         
@@ -337,6 +342,7 @@ class compNet(nn.Module):
         Perm = Permutation_Matrix(Ord)
         Pmat = np.dot(Perm,H);
         Pmat = Pmat[:M,:];
+        self.Pmat = Pmat
         Pconv = matrix2conv(Pmat);
 
         #-- Denoising parameters 
@@ -527,7 +533,7 @@ class compNet(nn.Module):
 # B. NOISY MEASUREMENTS (NOISE LEVEL IS VARYING)
 #==============================================================================
 class noiCompNet(compNet):
-    def __init__(self, n, M, Mean, Cov, variant, N0=2500, sig=0.5, H=None, Ord=None):
+    def __init__(self, n, M, Mean, Cov, variant=0, N0=2500, sig=0.0, H=None, Ord=None):
         super().__init__(n, M, Mean, Cov, variant, H, Ord)
         self.N0 = N0;
         self.sig = sig;
@@ -600,7 +606,7 @@ class noiCompNet(compNet):
 # B. NOISY MEASUREMENTS (NOISE LEVEL IS VARYING) + denoising architecture
 #==============================================================================
 class DenoiCompNet(noiCompNet):
-    def __init__(self, n, M, Mean, Cov, variant=0, N0=2500, sig=0.5, H=None, Ord=None):
+    def __init__(self, n, M, Mean, Cov, variant=0, N0=2500, sig=0.0, H=None, Ord=None):
         super().__init__(n, M, Mean, Cov, variant, N0, sig, H, Ord)
         print("Denoised Measurements")
    
