@@ -14,7 +14,7 @@ Created on Wed Jan 15 16:48:37 2020
 import sys
 import numpy as np
 sys.path.append('/home/crombez/Documents/PhD/python/libreries/')
-from walsh_hadamard import walsh_ordered
+from misc.walsh_hadamard import walsh2
 
 
 def recon_Walsh(Data,n): # Return the product of the a 2D matrix with the Walsh ordered matrix of the same size
@@ -22,7 +22,7 @@ def recon_Walsh(Data,n): # Return the product of the a 2D matrix with the Walsh
 
 def recon_Walsh_evry_lambda(Data,Nl,Nc,Nh): # Return the products of the each 2D matrix of the 3D matrix with the Walsh ordered matrix of the same size
     M_recon = np.zeros((Nl,Nh,Nc))
-    Waslh = walsh_ordered(Nh)
+    Waslh = walsh2(Nh)
     for i in range(Nc):
         M_recon[:,:,i] = np.dot(Data[:,i,:],Waslh)
     return(M_recon)   
